# Generated by Django 4.2.1 on 2023-07-07 19:32

import edc_sites.models
from django.db import migrations

import edc_locator.model_mixins.locator_model_mixin


class Migration(migrations.Migration):
    dependencies = [
        ("edc_locator", "0031_alter_subjectlocator_options"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="subjectlocator",
            managers=[
                (
                    "objects",
                    edc_locator.model_mixins.locator_model_mixin.LocatorManager(),
                ),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]
