# Generated by Django 2.0.1 on 2018-01-17 16:19

import edc_sites.models
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [("edc_locator", "0006_auto_20180116_1528")]

    operations = [
        migrations.AlterModelManagers(
            name="subjectlocator",
            managers=[("on_site", edc_sites.models.CurrentSiteManager())],
        )
    ]
